declare const _default: import("vue").DefineComponent<import("vue").ExtractPropTypes<{
    /**
     * Title that appears above the main card title
     */
    subheading: {
        type: StringConstructor;
        required: false;
    };
    /**
     * Heading text for the card option. Usually you can put what you pass to optionValue in here
     */
    heading: {
        type: StringConstructor;
        required: false;
    };
    /**
     * Option value for the underlying checkbox options. **If the optionValue is an Object, control the identifier which the component checks the selected option with the  `identifierToMatchOptionValue` prop**
     */
    optionValue: {
        type: (ObjectConstructor | StringConstructor)[];
        required: true;
    };
    /**
     * Value comes from the wrapping component to communicate which option the user has selected so that radio card can set the "checked" styles.
     */
    modelValue: {
        type: (ObjectConstructor | StringConstructor)[];
        required: true;
    };
    /**
     * HTML name attribute for the radio button to group them together. This name should be the same for a group of radio buttons. ie. if you're looping over options, they will all pass the same name.
     */
    name: {
        type: StringConstructor;
        required: true;
    };
    /**
     * Additional info that goes below the main heading
     */
    additionalInfo: {
        type: StringConstructor;
        required: false;
    };
    /**
     * Control whether the checkbox is on the left or right of the input. Default (not reverse) is to the right.
     */
    reverse: {
        type: BooleanConstructor;
        required: false;
        default: boolean;
    };
    /**
     * Text for the optional label that sits on top of the input
     */
    labelText: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Background color class for the input label
     */
    labelBgColorClass: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Border color class for the option card selected state (only applies when the `contextual-info` slot is populated)
     */
    selectedCardBorderColorClass: {
        type: StringConstructor;
        required: false;
        default: string;
        validator: (prop: unknown) => boolean;
    };
    /**
     * Label for inline answer. Determines whether it is used or not.
     */
    inlineAnswerLabel: {
        type: StringConstructor;
        default: string;
    };
    /**
     * If this prop is true, component must be used inside AppOptionGroup`
     */
    asGroupItem: {
        type: BooleanConstructor;
        required: false;
        default: boolean;
    };
    /**
     * If `optionValue` is an object, then you can pass in an identifier to match the selected option off of. Defaults to `id`
     */
    identifierToMatchOptionValue: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Determines the vertical alignment of the arrow icon or pseudo radio circle icon.
     */
    verticalIconPosition: {
        type: StringConstructor;
        required: false;
        default: string;
        validator: (prop: unknown) => boolean;
    };
    /**
     * Controls the size of the button.
     */
    buttonSize: {
        type: StringConstructor;
        required: false;
        default: string;
        validator: (prop: unknown) => boolean;
    };
    /**
     * Label for placeholder text. This is only used for the condensed button size. Determines whether it is used or not.
     */
    placeholderLabel: {
        type: StringConstructor;
        default: string;
    };
}>, {}, {
    currentlyKeyboardFocused: boolean;
}, {
    inlineAnswerValue: {
        get(): any;
        set(newValue: any): void;
    };
    checked: {
        get(): string | Record<string, any>;
        set(newValue: any): void;
    };
    dividerBgColorClass(): "fx-bg-green-100" | "fx-bg-brown-100" | "fx-bg-brown-50";
    isInlineAnswerExpanded(): boolean;
    getVerticalIconPositionClass(): "fx-self-start" | "fx-self-center" | "fx-self-end";
    isCondensedSize(): boolean;
}, {
    isChecked(option: any): boolean;
    hasSlot(slotName: any): boolean;
    /**
     * `data-focus-visible-added gets added from the focus visible polyfill https://github.com/WICG/focus-visible. Since currently :focus-within is not supported with combination of :focus-visible, we have to do some manual work to check to see if the input is focused, and then bind to the class on the wrapping component we want to style
     */
    checkIfInputIsKeyboardFocused(): void;
    inlineAnswerInput(value: any): void;
    getHeadingClasses(): "md:fx-text-base md:fx-font-regular fx-font-regular" | "md:fx-text-lg md:fx-font-bold fx-font-bold";
}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
    /**
     * Title that appears above the main card title
     */
    subheading: {
        type: StringConstructor;
        required: false;
    };
    /**
     * Heading text for the card option. Usually you can put what you pass to optionValue in here
     */
    heading: {
        type: StringConstructor;
        required: false;
    };
    /**
     * Option value for the underlying checkbox options. **If the optionValue is an Object, control the identifier which the component checks the selected option with the  `identifierToMatchOptionValue` prop**
     */
    optionValue: {
        type: (ObjectConstructor | StringConstructor)[];
        required: true;
    };
    /**
     * Value comes from the wrapping component to communicate which option the user has selected so that radio card can set the "checked" styles.
     */
    modelValue: {
        type: (ObjectConstructor | StringConstructor)[];
        required: true;
    };
    /**
     * HTML name attribute for the radio button to group them together. This name should be the same for a group of radio buttons. ie. if you're looping over options, they will all pass the same name.
     */
    name: {
        type: StringConstructor;
        required: true;
    };
    /**
     * Additional info that goes below the main heading
     */
    additionalInfo: {
        type: StringConstructor;
        required: false;
    };
    /**
     * Control whether the checkbox is on the left or right of the input. Default (not reverse) is to the right.
     */
    reverse: {
        type: BooleanConstructor;
        required: false;
        default: boolean;
    };
    /**
     * Text for the optional label that sits on top of the input
     */
    labelText: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Background color class for the input label
     */
    labelBgColorClass: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Border color class for the option card selected state (only applies when the `contextual-info` slot is populated)
     */
    selectedCardBorderColorClass: {
        type: StringConstructor;
        required: false;
        default: string;
        validator: (prop: unknown) => boolean;
    };
    /**
     * Label for inline answer. Determines whether it is used or not.
     */
    inlineAnswerLabel: {
        type: StringConstructor;
        default: string;
    };
    /**
     * If this prop is true, component must be used inside AppOptionGroup`
     */
    asGroupItem: {
        type: BooleanConstructor;
        required: false;
        default: boolean;
    };
    /**
     * If `optionValue` is an object, then you can pass in an identifier to match the selected option off of. Defaults to `id`
     */
    identifierToMatchOptionValue: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Determines the vertical alignment of the arrow icon or pseudo radio circle icon.
     */
    verticalIconPosition: {
        type: StringConstructor;
        required: false;
        default: string;
        validator: (prop: unknown) => boolean;
    };
    /**
     * Controls the size of the button.
     */
    buttonSize: {
        type: StringConstructor;
        required: false;
        default: string;
        validator: (prop: unknown) => boolean;
    };
    /**
     * Label for placeholder text. This is only used for the condensed button size. Determines whether it is used or not.
     */
    placeholderLabel: {
        type: StringConstructor;
        default: string;
    };
}>> & Readonly<{}>, {
    reverse: boolean;
    buttonSize: string;
    labelText: string;
    labelBgColorClass: string;
    inlineAnswerLabel: string;
    asGroupItem: boolean;
    identifierToMatchOptionValue: string;
    selectedCardBorderColorClass: string;
    verticalIconPosition: string;
    placeholderLabel: string;
}, {}, {
    AppLabel: import("vue").DefineComponent<import("vue").ExtractPropTypes<{
        text: {
            type: StringConstructor;
            required: true;
        };
        position: {
            default: string;
            validator: (prop: unknown) => boolean;
        };
        bgColorClass: {
            type: StringConstructor;
            default: string;
        };
        offsetClass: {
            type: StringConstructor;
            default: string;
        };
    }>, {}, {}, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
        text: {
            type: StringConstructor;
            required: true;
        };
        position: {
            default: string;
            validator: (prop: unknown) => boolean;
        };
        bgColorClass: {
            type: StringConstructor;
            default: string;
        };
        offsetClass: {
            type: StringConstructor;
            default: string;
        };
    }>> & Readonly<{}>, {
        bgColorClass: string;
        position: string;
        offsetClass: string;
    }, {}, {}, {}, string, import("vue").ComponentProvideOptions, true, {}, any>;
    AppDivider: import("vue").DefineComponent<import("vue").ExtractPropTypes<{
        orientation: {
            type: StringConstructor;
            default: string;
            validator: (value: unknown) => boolean;
            required: false;
        };
        thickness: {
            type: StringConstructor;
            default: string;
            validator: (value: unknown) => boolean;
            required: false;
        };
    }>, {}, {
        dividerClasses: {
            horizontal: string;
            vertical: string;
        };
    }, {}, {
        getHeightClassOnThickness(): "fx-h-[0.5px]" | "fx-h-[1px]" | "fx-h-[2px]";
        getWidthClassOnThickness(): "fx-w-[0.5px]" | "fx-w-[1px]" | "fx-w-[2px]";
    }, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
        orientation: {
            type: StringConstructor;
            default: string;
            validator: (value: unknown) => boolean;
            required: false;
        };
        thickness: {
            type: StringConstructor;
            default: string;
            validator: (value: unknown) => boolean;
            required: false;
        };
    }>> & Readonly<{}>, {
        orientation: string;
        thickness: string;
    }, {}, {}, {}, string, import("vue").ComponentProvideOptions, true, {}, any>;
    AppInputMultiLine: any;
    AdditionalInfo: any;
}, {}, string, import("vue").ComponentProvideOptions, true, {}, any>;
export default _default;
