declare const _default: import("vue").DefineComponent<import("vue").ExtractPropTypes<{
    /**
     * Array of objects that define the contents inside the menu
     * [
     *  {
     *    displayName: 'string',
     *    type: 'action' | 'external' | 'divider'
     *    action: onClick | 'https://www.google.ca/some-external-route/'
     *    newWindow: boolean,
     *    itemColor: 'red-100'
     *  },
     *  ...
     * ]
     */
    items: {
        type: ArrayConstructor;
        required: true;
        default: () => any[];
    };
    /**
     * Menu title to be displayed on the button
     */
    menuButtonName: {
        type: StringConstructor;
        required: true;
        default: string;
    };
    /**
     * Boolean value that controls if we show a down arrow (chevron) beside the button name
     * Defaults to true
     */
    showChevron: {
        type: BooleanConstructor;
        default: boolean;
        required: false;
    };
    /**
     * Applies an ID to the <button> that is linked to the menu <ul>'s aria-labelledBy attribute
     */
    triggerButtonId: {
        type: StringConstructor;
        required: true;
    };
    /**
     * Aligns the inner content menu section to the `right` or `left` side of the button
     * Defaults to the left side
     */
    menuAlignment: {
        type: StringConstructor;
        required: false;
        default: string;
        validator: (prop: unknown) => boolean;
    };
    /**
     * Boolean value that controls if the menu has full width dividers
     * Not necessary if the menu items don't include the 'divider' type
     * See AppMenuItem.vue for more information
     */
    hasFullWidthDividers: {
        type: BooleanConstructor;
        required: false;
        default: boolean;
    };
    /**
     * Controls thickness of the divider
     * See AppDivider.vue for more information
     */
    dividerThickness: {
        string: number;
        default: string;
        required: false;
        validator: (value: unknown) => boolean;
    };
}>, {}, {
    displayMenu: boolean;
    customTabIndex: number;
}, {}, {
    handleDownPress(): void;
    handleUpPress(): void;
    focusElement(element: any): void;
    selectItem(): void;
    handleEscPress(): void;
    onClick(): void;
    onClickOutside(): void;
    openMenu(): void;
    closeMenu(): void;
}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
    /**
     * Array of objects that define the contents inside the menu
     * [
     *  {
     *    displayName: 'string',
     *    type: 'action' | 'external' | 'divider'
     *    action: onClick | 'https://www.google.ca/some-external-route/'
     *    newWindow: boolean,
     *    itemColor: 'red-100'
     *  },
     *  ...
     * ]
     */
    items: {
        type: ArrayConstructor;
        required: true;
        default: () => any[];
    };
    /**
     * Menu title to be displayed on the button
     */
    menuButtonName: {
        type: StringConstructor;
        required: true;
        default: string;
    };
    /**
     * Boolean value that controls if we show a down arrow (chevron) beside the button name
     * Defaults to true
     */
    showChevron: {
        type: BooleanConstructor;
        default: boolean;
        required: false;
    };
    /**
     * Applies an ID to the <button> that is linked to the menu <ul>'s aria-labelledBy attribute
     */
    triggerButtonId: {
        type: StringConstructor;
        required: true;
    };
    /**
     * Aligns the inner content menu section to the `right` or `left` side of the button
     * Defaults to the left side
     */
    menuAlignment: {
        type: StringConstructor;
        required: false;
        default: string;
        validator: (prop: unknown) => boolean;
    };
    /**
     * Boolean value that controls if the menu has full width dividers
     * Not necessary if the menu items don't include the 'divider' type
     * See AppMenuItem.vue for more information
     */
    hasFullWidthDividers: {
        type: BooleanConstructor;
        required: false;
        default: boolean;
    };
    /**
     * Controls thickness of the divider
     * See AppDivider.vue for more information
     */
    dividerThickness: {
        string: number;
        default: string;
        required: false;
        validator: (value: unknown) => boolean;
    };
}>> & Readonly<{}>, {
    hasFullWidthDividers: boolean;
    dividerThickness: string;
    items: unknown[];
    menuButtonName: string;
    showChevron: boolean;
    menuAlignment: string;
}, {}, {
    AppMenuItem: import("vue").DefineComponent<import("vue").ExtractPropTypes<{
        item: {
            type: ObjectConstructor;
            required: true;
        };
        hasFullWidthDividers: {
            type: BooleanConstructor;
            required: false;
            default: boolean;
        };
        dividerThickness: {
            string: number;
            default: string;
            required: false;
            validator: (value: unknown) => boolean;
        };
    }>, {}, {}, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
        item: {
            type: ObjectConstructor;
            required: true;
        };
        hasFullWidthDividers: {
            type: BooleanConstructor;
            required: false;
            default: boolean;
        };
        dividerThickness: {
            string: number;
            default: string;
            required: false;
            validator: (value: unknown) => boolean;
        };
    }>> & Readonly<{}>, {
        hasFullWidthDividers: boolean;
        dividerThickness: string;
    }, {}, {
        AppDivider: any;
        AppTextButton: import("vue").DefineComponent<import("vue").ExtractPropTypes<{
            size: {
                type: (StringConstructor | ArrayConstructor)[];
                required: false;
                default: string;
                validator: (prop: unknown) => boolean;
            };
            type: {
                type: StringConstructor;
                required: true;
                validator: (prop: unknown) => boolean;
            };
            icon: {
                type: StringConstructor;
                required: false;
                default: string;
                validator: (prop: unknown) => boolean;
            };
            inline: {
                type: BooleanConstructor;
                required: false;
                default: boolean;
            };
            underline: {
                type: BooleanConstructor;
                required: false;
                default: boolean;
            };
            color: {
                type: StringConstructor;
                default: any;
                validator: (prop: unknown) => boolean;
                required: false;
            };
        }>, {}, {}, {
            buttonType(): "button" | "a";
            buttonClasses(): string;
            hasIconSlot(): import("vue").Slot<any>;
            iconClasses(): string;
            textClasses(): string;
            sizeClass(): "" | "fx-text-base" | "fx-text-sm" | "fx-text-lg";
            paddingClass(): "" | "fx-py-12 md:fx-py-0" | "fx-py-[10px] md:fx-py-0";
            desktopSizeClass(): "" | "md:fx-text-sm" | "md:fx-text-md" | "md:fx-text-lg";
            iconClass(): "fx-h-[20px] fx-w-[20px]" | "fx-h-[24px] fx-w-[24px]" | "fx-h-[28px] fx-w-[28px]";
            colorClass(): any;
        }, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
            size: {
                type: (StringConstructor | ArrayConstructor)[];
                required: false;
                default: string;
                validator: (prop: unknown) => boolean;
            };
            type: {
                type: StringConstructor;
                required: true;
                validator: (prop: unknown) => boolean;
            };
            icon: {
                type: StringConstructor;
                required: false;
                default: string;
                validator: (prop: unknown) => boolean;
            };
            inline: {
                type: BooleanConstructor;
                required: false;
                default: boolean;
            };
            underline: {
                type: BooleanConstructor;
                required: false;
                default: boolean;
            };
            color: {
                type: StringConstructor;
                default: any;
                validator: (prop: unknown) => boolean;
                required: false;
            };
        }>> & Readonly<{}>, {
            size: string | unknown[];
            icon: string;
            color: string;
            inline: boolean;
            underline: boolean;
        }, {}, {}, {}, string, import("vue").ComponentProvideOptions, true, {}, any>;
    }, {}, string, import("vue").ComponentProvideOptions, true, {}, any>;
    ChevronDown: any;
}, {
    clickOutside: {
        beforeMount(el: any, binding: import("vue").DirectiveBinding<any, string, string>): void;
        unmounted(el: any): void;
    };
}, string, import("vue").ComponentProvideOptions, true, {}, any>;
export default _default;
